#ifndef NDS_LOG_MATLAB_H
#define NDS_LOG_MATLAB_H

#include "nds_logging.h"

#ifndef DLL_EXPORT
#if defined _WIN32 || defined _WIN64
#define DLL_EXPORT __declspec(dllexport)
#else
#define DLL_EXPORT
#endif /* _WIN32 || _WIN64 */
#endif /* DLL_EXPORT */

DLL_EXPORT void nds_flush_matlab( );

DLL_EXPORT void nds_log_matlab( const char* Message );

DLL_EXPORT void NDS_LOGGING_HELPER_ENTRY( );

#endif /* NDS_LOG_MATLAB_H */
